==> bmtk_1.0.6+ds.orig.tar.xz: bmtk-1.0.6/bmtk/simulator/bionet/config.py <==
# Copyright 2017. Allen Institute. All rights reserved
#
# Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
# following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following
# disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following
# disclaimer in the documentation and/or other materials provided with the distribution.
#
# 3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote
# products derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
import os
import json

from neuron import h

from bmtk.simulator.core.simulation_config import SimulationConfig
from bmtk.simulator.bionet.io_tools import io
from . import nrn


pc = h.ParallelContext()    # object to access MPI methods
MPI_Rank = int(pc.id())


class Config(SimulationConfig):
    def create_output_dir(self):
        io.setup_output_dir(self.output_dir, self.log_file)

    def load_nrn_modules(self):
        nrn.load_neuron_modules(self.mechanisms_dir, self.templates_dir)

    def build_env(self):
        self.io = io
        self._set_logging()
        self.create_output_dir()
        self.copy_to_output()
        if io.mpi_size > 1:
            # A friendly message requested by fb
            io.log_info('Running NEURON with mpi ({} cores).'.format(io.mpi_size))

        pc.barrier()
        self.load_nrn_modules()

==> bmtk_1.1.1+ds.orig.tar.xz: bmtk-1.1.1/bmtk/simulator/bionet/config.py <==
# Copyright 2017. Allen Institute. All rights reserved
#
# Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
# following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following
# disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following
# disclaimer in the documentation and/or other materials provided with the distribution.
#
# 3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote
# products derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
import os
import json

from neuron import h

from bmtk.simulator.core.simulation_config import SimulationConfig
from bmtk.simulator.bionet.io_tools import io
from . import nrn


pc = h.ParallelContext()    # object to access MPI methods
MPI_Rank = int(pc.id())


class Config(SimulationConfig):
    def create_output_dir(self):
        io.setup_output_dir(self.output_dir, self.log_file)

    def load_nrn_modules(self):
        nrn.load_neuron_modules(
            mechanisms_dir=self.mechanisms_dir, 
            templates_dir=self.templates_dir, 
            default_templates=self.use_default_templates,
            use_old_import3d=self.use_old_import3d
        )

    def build_env(self):
        self.io = io
        self._set_logging()
        self.create_output_dir()
        self.copy_to_output()
        if io.mpi_size > 1:
            # A friendly message requested by fb
            io.log_info('Running NEURON with mpi ({} cores).'.format(io.mpi_size))

        pc.barrier()
        self.load_nrn_modules()

    def _set_class_props(self):
        super(Config, self)._set_class_props()
        self.use_old_import3d = self.run.get('use_old_import3d', False)
        self.use_default_templates = self.run.get('use_old_import3d', True)
